==> korweblog-1.5.8.tar.gz: korweblog-1.5.8/include/javabox.inc.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001,2002 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

/* base on <http://jsboard.kldp.org> */
function KWL_MouseOverInit() {
   global $agent , $LAYOUT;

   if($agent['br'] == "MSIE") {
    $script_for_browser = "  over = overDiv.style;\n".
                          "  document.onmousemove = mouseMove;\n\n".

                          "  function drs(text, title) { dts(1,text); }\n\n".

                          "  function nd() {\n".
                          "    if ( cnt >= 1 ) { sw = 0 };\n".
                          "    if ( sw == 0 ) { snow = 0; hideObject(over); }\n".
                          "    else { cnt++; }\n".
                          "  }\n\n".

                          "  function dts(d,text) {\n".
                          "    txt = \"<TABLE WIDTH=\"+width+\" BORDER=1 CELLPADDING=\"+border+\" CELLSPACING=0><TR><TD BGCOLOR=\"+backcolor+\"><FONT SIZE=-1 COLOR=\"+textcolor+\">\"+text+\"</FONT></TD></TR></TABLE>\";\n".
                          "    layerWrite(txt);\n".
                          "    dir = d;\n".
                          "    disp();\n".
                          "  }\n\n".

                          "  function disp() {\n".
                          "    if (snow == 0) {\n".
                          "      if (dir == 2) { moveTo(over,x+offsetx-(width/2),y+offsety); } // Center\n".
                          "      if (dir == 1) { moveTo(over,x+offsetx,y+offsety); } // Right\n".
                          "      if (dir == 0) { moveTo(over,x-offsetx-width,y+offsety); } // Left\n".
                          "      showObject(over);\n".
                          "      snow = 1;\n".
                          "    }\n".
                          "  }\n\n".

                          "  function mouseMove(e) {\n".
                          "    x=event.x + document.body.scrollLeft+10\n".
                          "    y=event.y + document.body.scrollTop\n".
                          "    if (x+width-document.body.scrollLeft > document.body.clientWidth) x=x-width-25;\n".
                          "    if (y+height-document.body.scrollTop > document.body.clientHeight) y=y-height;\n\n".

                          "    if (snow) {\n".
                          "      if (dir == 2) { moveTo(over,x+offsetx-(width/2),y+offsety); } // Center\n".
                          "      if (dir == 1) { moveTo(over,x+offsetx,y+offsety); } // Right\n".
                          "      if (dir == 0) { moveTo(over,x-offsetx-width,y+offsety); } // Left\n".
                          "    }\n".
                          "  }\n\n".

                          "  function cClick() { hideObject(over); sw=0; }\n".
                          "  function layerWrite(txt) { document.all[\"overDiv\"].innerHTML = txt }\n".
                          "  function showObject(obj) { obj.visibility = \"visible\" }\n".
                          "  function hideObject(obj) { obj.visibility = \"hidden\" }\n".
                          "  function moveTo(obj,xL,yL) { obj.left = xL; obj.top = yL; }";
  } elseif($agent['br'] == "MOZL6") {
    $script_for_browser = "  over = document.getElementById('overDiv');\n".
                          "  document.onmousemove = mouseMove;\n".
                          "  document.captureEvents(Event.MOUSEMOVE);\n\n".

                          " function drs(text, title) { dts(1,text); }\n\n".

                          "  function nd() {\n".
                          "    if ( cnt >= 1 ) { sw = 0 };\n".
                          "    if ( sw == 0 ) {\n".
                          "        snow = 0;\n".
                          "        hideObject(over);\n".
                          "    } else { cnt++; }\n".
                          "  }\n\n".


                          "  function dts(d,text) {\n".
                          "    txt = \"<TABLE WIDTH=\"+width+\" BORDER=1 CELLPADDING=\"+border+\" CELLSPACING=0><TR><TD BGCOLOR=\"+backcolor+\"><FONT SIZE=-1 COLOR=\"+textcolor+\">\"+text+\"</FONT></TD></TR></TABLE>\";\n".
                          "    layerWrite(txt);\n".
                          "    dir = d;\n".
                          "    disp();\n".
                          "  }\n\n".

                          "  function disp() {\n".
                          "      if (snow == 0) {\n".
                          "        if (dir == 2) { moveTo(over,x+offsetx-(width/2),y+offsety); } // Center\n".
                          "        if (dir == 1) { moveTo(over,x+offsetx,y+offsety); } // Right\n".
                          "        if (dir == 0) { moveTo(over,x-offsetx-width,y+offsety); } // Left\n".
                          "        showObject(over);\n".
                          "        snow = 1;\n".
                          "      }\n".
                          "  }\n\n".

                          "  function mouseMove(e) {\n".
                          "        x=( (e.pageX)+width-window.pageXOffset > window.innerWidth ) ? (e.pageX+10)-width-10 : e.pageX+10;\n".
                          "        y=( (e.pageY)+height-self.pageYOffset > window.innerHeight ) ? (e.pageY)-height+5 : e.pageY;\n\n".

                          "    if (snow) {\n".
                          "      if (dir == 2) { moveTo(over,x+offsetx-(width/2),y+offsety); } // Center\n".
                          "      if (dir == 1) { moveTo(over,x+offsetx,y+offsety); } // Right\n".
                          "      if (dir == 0) { moveTo(over,x-offsetx-width,y+offsety); } // Left\n".
                          "    }\n".
                          "  }\n\n".

                          "  function cClick() { hideObject(over); sw=0; }\n".
                          "  function layerWrite(txt) { over.innerHTML = txt; }\n".
                          "  function showObject(obj) { obj.style.visibility = \"visible\"; }\n".
                          "  function hideObject(obj) { obj.style.visibility = \"hidden\"; }\n".
                          "  function moveTo(obj,xL,yL) {\n".
                          "    obj.style.left = xL\n".
                          "    obj.style.top = yL\n".
                          "  }";
  } elseif($agent['br'] == "MOZL") {
    $script_for_browser = "  over = document.overDiv;\n".
                          "  document.onmousemove = mouseMove;\n".
                          "  document.captureEvents(Event.MOUSEMOVE);\n\n".

                          "  function drs(text, title) { dts(1,text); }\n\n".

                          "  function nd() {\n".
                          "    if ( cnt >= 1 ) { sw = 0 };\n".
                          "    if ( sw == 0 ) { snow = 0; hideObject(over); }\n".
                          "    else { cnt++; }\n".
                          "  }\n\n".

                          "  function dts(d,text) {\n".
                          "    txt = \"<TABLE WIDTH=\"+width+\" BORDER=1 CELLPADDING=\"+border+\" CELLSPACING=0><TR><TD BGCOLOR=\"+backcolor+\"><FONT SIZE=-1 COLOR=\"+textcolor+\">\"+text+\"</FONT></TD></TR></TABLE>\";\n".
                          "    layerWrite(txt);\n".
                          "    dir = d;\n".
                          "    disp();\n".
                          "  }\n\n".

                          "  function disp() {\n".
                          "    if (snow == 0) {\n".
                          "      if (dir == 2) { moveTo(over,x+offsetx-(width/2),y+offsety); } // Center\n".
                          "      if (dir == 1) { moveTo(over,x+offsetx,y+offsety); } // Right\n".
                          "      if (dir == 0) { moveTo(over,x-offsetx-width,y+offsety); } // Left\n".
                          "      showObject(over);\n".
                          "      snow = 1;\n".
                          "    }\n".
                          "  }\n\n".

                          "  function mouseMove(e) {\n".
                          "    x=e.pageX+10;\n".
                          "    y=e.pageY;\n".
                          "    if (x+width-self.pageXOffset > window.innerWidth) x=x-width-5;\n".
                          "    if (y+height-self.pageYOffset > window.innerHeight) y=y-height;\n\n".

                          "    if (snow) {\n".
                          "      if (dir == 2) { moveTo(over,x+offsetx-(width/2),y+offsety); } // Center\n".
                          "      if (dir == 1) { moveTo(over,x+offsetx,y+offsety); } // Right\n".
                          "      if (dir == 0) { moveTo(over,x-offsetx-width,y+offsety); } // Left\n".
                          "    }\n".
                          "  }\n\n".

                          "  function cClick() { hideObject(over); sw=0; }\n\n".

                          "  function layerWrite(txt) {\n".
                          "      var lyr = document.overDiv.document;\n".
                          "      lyr.write(txt);\n".
                          "      lyr.close();\n".
                          "  }\n\n".

                          "  function showObject(obj) { obj.visibility = \"show\" }\n".
                          "  function hideObject(obj) { obj.visibility = \"hide\" }\n".
                          "  function moveTo(obj,xL,yL) { obj.left = xL; obj.top = yL; }";
  }

	echo "
<div id=\"overDiv\" style=\"position:absolute; visibility:hide; z-index: 1;\"></div>
<SCRIPT LANGUAGE=JavaScript>
var x = 0;
var y = 0;
var snow = 0;
var sw = 0;
var cnt = 0;
var dir = 1;
var offsetx = 3;
var offsety = 3;
var width = 250;
var height = 50;

var backcolor = \"$LAYOUT[BgColor]\";
var textcolor = \"$LAYOUT[FgColor]\";
var border = \"3\";

$script_for_browser
</SCRIPT>
";
}

function KWL_MouseOverBox($txt) {
   $txt = KWL_PrepareHtml($txt);
   $txt = eregi_replace("(\r*)\n","<BR>",$txt);
   $txt = eregi_replace("(#|'|\\\\)","\\\\1",$txt);
   return " onMouseOver=\"drs('$txt'); return true;\" onMouseOut=\"nd(); return true;\" ";
}
?>

==> korweblog-1.5.9.tar.gz: korweblog-1.5.9/include/javabox.inc.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

/* base on <http://jsboard.kldp.org> */
function KWL_MouseOverInit() {
   global $agent;

   if($agent['br'] == "MSIE") {
    $script_for_browser = "  over = overDiv.style;\n".
                          "  document.onmousemove = mouseMove;\n\n".

                          "  function drs(text, title) { dts(1,text); }\n\n".

                          "  function nd() {\n".
                          "    if ( cnt >= 1 ) { sw = 0 };\n".
                          "    if ( sw == 0 ) { snow = 0; hideObject(over); }\n".
                          "    else { cnt++; }\n".
                          "  }\n\n".

                          "  function dts(d,text) {\n".
                          "    txt = \"<TABLE WIDTH=\"+width+\" BORDER=1 CELLPADDING=\"+border+\" CELLSPACING=0><TR><TD BGCOLOR=\"+backcolor+\"><FONT SIZE=-1 COLOR=\"+textcolor+\">\"+text+\"</FONT></TD></TR></TABLE>\";\n".
                          "    layerWrite(txt);\n".
                          "    dir = d;\n".
                          "    disp();\n".
                          "  }\n\n".

                          "  function disp() {\n".
                          "    if (snow == 0) {\n".
                          "      if (dir == 2) { moveTo(over,x+offsetx-(width/2),y+offsety); } // Center\n".
                          "      if (dir == 1) { moveTo(over,x+offsetx,y+offsety); } // Right\n".
                          "      if (dir == 0) { moveTo(over,x-offsetx-width,y+offsety); } // Left\n".
                          "      showObject(over);\n".
                          "      snow = 1;\n".
                          "    }\n".
                          "  }\n\n".

                          "  function mouseMove(e) {\n".
                          "    x=event.x + document.body.scrollLeft+10\n".
                          "    y=event.y + document.body.scrollTop\n".
                          "    if (x+width-document.body.scrollLeft > document.body.clientWidth) x=x-width-25;\n".
                          "    if (y+height-document.body.scrollTop > document.body.clientHeight) y=y-height;\n\n".

                          "    if (snow) {\n".
                          "      if (dir == 2) { moveTo(over,x+offsetx-(width/2),y+offsety); } // Center\n".
                          "      if (dir == 1) { moveTo(over,x+offsetx,y+offsety); } // Right\n".
                          "      if (dir == 0) { moveTo(over,x-offsetx-width,y+offsety); } // Left\n".
                          "    }\n".
                          "  }\n\n".

                          "  function cClick() { hideObject(over); sw=0; }\n".
                          "  function layerWrite(txt) { document.all[\"overDiv\"].innerHTML = txt }\n".
                          "  function showObject(obj) { obj.visibility = \"visible\" }\n".
                          "  function hideObject(obj) { obj.visibility = \"hidden\" }\n".
                          "  function moveTo(obj,xL,yL) { obj.left = xL; obj.top = yL; }";
  } elseif($agent['br'] == "MOZL6") {
    $script_for_browser = "  over = document.getElementById('overDiv');\n".
                          "  document.onmousemove = mouseMove;\n".
                          "  document.captureEvents(Event.MOUSEMOVE);\n\n".

                          " function drs(text, title) { dts(1,text); }\n\n".

                          "  function nd() {\n".
                          "    if ( cnt >= 1 ) { sw = 0 };\n".
                          "    if ( sw == 0 ) {\n".
                          "        snow = 0;\n".
                          "        hideObject(over);\n".
                          "    } else { cnt++; }\n".
                          "  }\n\n".


                          "  function dts(d,text) {\n".
                          "    txt = \"<TABLE WIDTH=\"+width+\" BORDER=1 CELLPADDING=\"+border+\" CELLSPACING=0><TR><TD BGCOLOR=\"+backcolor+\"><FONT SIZE=-1 COLOR=\"+textcolor+\">\"+text+\"</FONT></TD></TR></TABLE>\";\n".
                          "    layerWrite(txt);\n".
                          "    dir = d;\n".
                          "    disp();\n".
                          "  }\n\n".

                          "  function disp() {\n".
                          "      if (snow == 0) {\n".
                          "        if (dir == 2) { moveTo(over,x+offsetx-(width/2),y+offsety); } // Center\n".
                          "        if (dir == 1) { moveTo(over,x+offsetx,y+offsety); } // Right\n".
                          "        if (dir == 0) { moveTo(over,x-offsetx-width,y+offsety); } // Left\n".
                          "        showObject(over);\n".
                          "        snow = 1;\n".
                          "      }\n".
                          "  }\n\n".

                          "  function mouseMove(e) {\n".
                          "        x=( (e.pageX)+width-window.pageXOffset > window.innerWidth ) ? (e.pageX+10)-width-10 : e.pageX+10;\n".
                          "        y=( (e.pageY)+height-self.pageYOffset > window.innerHeight ) ? (e.pageY)-height+5 : e.pageY;\n\n".

                          "    if (snow) {\n".
                          "      if (dir == 2) { moveTo(over,x+offsetx-(width/2),y+offsety); } // Center\n".
                          "      if (dir == 1) { moveTo(over,x+offsetx,y+offsety); } // Right\n".
                          "      if (dir == 0) { moveTo(over,x-offsetx-width,y+offsety); } // Left\n".
                          "    }\n".
                          "  }\n\n".

                          "  function cClick() { hideObject(over); sw=0; }\n".
                          "  function layerWrite(txt) { over.innerHTML = txt; }\n".
                          "  function showObject(obj) { obj.style.visibility = \"visible\"; }\n".
                          "  function hideObject(obj) { obj.style.visibility = \"hidden\"; }\n".
                          "  function moveTo(obj,xL,yL) {\n".
                          "    obj.style.left = xL\n".
                          "    obj.style.top = yL\n".
                          "  }";
  } elseif($agent['br'] == "MOZL") {
    $script_for_browser = "  over = document.overDiv;\n".
                          "  document.onmousemove = mouseMove;\n".
                          "  document.captureEvents(Event.MOUSEMOVE);\n\n".

                          "  function drs(text, title) { dts(1,text); }\n\n".

                          "  function nd() {\n".
                          "    if ( cnt >= 1 ) { sw = 0 };\n".
                          "    if ( sw == 0 ) { snow = 0; hideObject(over); }\n".
                          "    else { cnt++; }\n".
                          "  }\n\n".

                          "  function dts(d,text) {\n".
                          "    txt = \"<TABLE WIDTH=\"+width+\" BORDER=1 CELLPADDING=\"+border+\" CELLSPACING=0><TR><TD BGCOLOR=\"+backcolor+\"><FONT SIZE=-1 COLOR=\"+textcolor+\">\"+text+\"</FONT></TD></TR></TABLE>\";\n".
                          "    layerWrite(txt);\n".
                          "    dir = d;\n".
                          "    disp();\n".
                          "  }\n\n".

                          "  function disp() {\n".
                          "    if (snow == 0) {\n".
                          "      if (dir == 2) { moveTo(over,x+offsetx-(width/2),y+offsety); } // Center\n".
                          "      if (dir == 1) { moveTo(over,x+offsetx,y+offsety); } // Right\n".
                          "      if (dir == 0) { moveTo(over,x-offsetx-width,y+offsety); } // Left\n".
                          "      showObject(over);\n".
                          "      snow = 1;\n".
                          "    }\n".
                          "  }\n\n".

                          "  function mouseMove(e) {\n".
                          "    x=e.pageX+10;\n".
                          "    y=e.pageY;\n".
                          "    if (x+width-self.pageXOffset > window.innerWidth) x=x-width-5;\n".
                          "    if (y+height-self.pageYOffset > window.innerHeight) y=y-height;\n\n".

                          "    if (snow) {\n".
                          "      if (dir == 2) { moveTo(over,x+offsetx-(width/2),y+offsety); } // Center\n".
                          "      if (dir == 1) { moveTo(over,x+offsetx,y+offsety); } // Right\n".
                          "      if (dir == 0) { moveTo(over,x-offsetx-width,y+offsety); } // Left\n".
                          "    }\n".
                          "  }\n\n".

                          "  function cClick() { hideObject(over); sw=0; }\n\n".

                          "  function layerWrite(txt) {\n".
                          "      var lyr = document.overDiv.document;\n".
                          "      lyr.write(txt);\n".
                          "      lyr.close();\n".
                          "  }\n\n".

                          "  function showObject(obj) { obj.visibility = \"show\" }\n".
                          "  function hideObject(obj) { obj.visibility = \"hide\" }\n".
                          "  function moveTo(obj,xL,yL) { obj.left = xL; obj.top = yL; }";
  }

	echo "
<div id=\"overDiv\" style=\"position:absolute; visibility:hide; z-index: 1;\"></div>
<SCRIPT LANGUAGE=JavaScript>
var x = 0;
var y = 0;
var snow = 0;
var sw = 0;
var cnt = 0;
var dir = 1;
var offsetx = 3;
var offsety = 3;
var width = 250;
var height = 50;

var backcolor = \"#ffffff\";
var textcolor = \"#000000\";
var border = \"3\";

$script_for_browser
</SCRIPT>
";
}

function KWL_MouseOverBox($txt) {
   $txt = KWL_PrepareHtml($txt);
   $txt = eregi_replace("(\r*)\n","<BR>",$txt);
   $txt = eregi_replace("(#|'|\\\\)","\\\\1",$txt);
   return " onMouseOver=\"drs('$txt'); return true;\" onMouseOut=\"nd(); return true;\" ";
}
?>
